/** 
 * Below we have parameters for the program 
 * You can use standard CAPD operations on intervals
 * to create rigorous bounds for any of the parameters
 * for example if you want tau = 0.05 (1/20), which is
 * not representable in double precision arithemtic then
 * you need to provide enclosure for tau, for example using 
 * operations on representable reals:
 * tau = interval(1.0) / interval(20.0);
 */
 
/** kappa from [V] */
interval KAPPA = 1.0;
/** tau from [V] */
interval TAU = interval(1.0) / interval(20.0);
/** gamma from [V] */
interval GAMMA = -1.0;
/** chi from [V] */
interval CHI = 4.0;
/** bound on xi */
interval XI = interval((interval(-4.0) - interval(49882477)/interval(1000000000)).leftBound(), (interval(-4.0) - interval(49880977)/interval(1000000000)).rightBound());

/** if loKSImode is true then the lo bound for Xi will be shifted with the aproximate value of \xi_{cr} */
bool loKSIMode = false;
/** if upKSImode is true then the up bound for Xi will be shifted with the aproximate value of \xi_{cr} */
bool upKSIMode = false;

/** S set size, S = z_0 + M_S ([-a_S, a_S] x [-b_S, b_S]) */
double a_S = 0.00005;
double b_S = 0.01;
/** U set size, U = z_0 + M_U ([-a_U, a_U] x [-b_U, b_U]) */
double a_U = 0.005;
double b_U = 0.0001; 
/** step size (h) for taylor numeric integration methods */
double step = 0.0001; 
/** order for taylor numeric integration methods */
int order = 8;
